summaryrefslogtreecommitdiffstats
path: root/src/H5FDdirect.c
diff options
context:
space:
mode:
authorDana Robinson <43805+derobins@users.noreply.github.com>2022-06-24 03:16:21 (GMT)
committerGitHub <noreply@github.com>2022-06-24 03:16:21 (GMT)
commitac7bddf2af317d4bc34854f5565396da51ff12aa (patch)
treef06f4267731f53e29da848d7d043950ec023f0b3 /src/H5FDdirect.c
parent50b3fb09a79cf94064d09087df6c44e680adc3a8 (diff)
downloadhdf5-ac7bddf2af317d4bc34854f5565396da51ff12aa.zip
hdf5-ac7bddf2af317d4bc34854f5565396da51ff12aa.tar.gz
hdf5-ac7bddf2af317d4bc34854f5565396da51ff12aa.tar.bz2
VFD SWMR: sync with develop (#1825)
* bin directory sync * doxygen changes * C++ sync with develop * Fortran sync with develop * Sync various docs with develop * Java sync with develop * More doxygen sync with develop * tools sync with develop * h5test.h testing macros get enclosed in do..while loops (#1721) * Minor examples normalization with develop * hl sync with develop * sprintf to snprintf (#1815) * Misc sync w/ develop * Brings some selection I/O bits over from develop * Brings over some const fixes from develop * Brings over more const bits from develop * Minor bits missed in early syncs * Brings over rest of selection I/O * Sync of mirror VFD changes w/ develop * Committing clang-format changes * Adds missing testpar file Co-authored-by: github-actions <41898282+github-actions[bot]@users.noreply.github.com>
Diffstat (limited to 'src/H5FDdirect.c')
-rw-r--r--src/H5FDdirect.c14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/H5FDdirect.c b/src/H5FDdirect.c
index 66843e9..b14060e 100644
--- a/src/H5FDdirect.c
+++ b/src/H5FDdirect.c
@@ -144,6 +144,7 @@ static herr_t H5FD__direct_ctl(H5FD_t *_file, uint64_t op_code, uint64_t flags,
void **output);
static const H5FD_class_t H5FD_direct_g = {
+ H5FD_CLASS_VERSION, /* struct version */
H5FD_DIRECT_VALUE, /* value */
"direct", /* name */
MAXADDR, /* maxaddr */
@@ -172,6 +173,10 @@ static const H5FD_class_t H5FD_direct_g = {
H5FD__direct_get_handle, /* get_handle */
H5FD__direct_read, /* read */
H5FD__direct_write, /* write */
+ NULL, /* read_vector */
+ NULL, /* write_vector */
+ NULL, /* read_selection */
+ NULL, /* write_selection */
NULL, /* flush */
H5FD__direct_truncate, /* truncate */
H5FD__direct_lock, /* lock */
@@ -1438,15 +1443,12 @@ done:
* input and output
*
* At present, the only op code supported is
* H5FD_CTL__GET_TERMINAL_VFD, which is used to obtain the
* instance of H5FD_t associated with the terminal
* VFD. This allows comparison of files whose terminal
* VFD may have overlying pass through VFDs.
*
* Return: Non-negative on success/Negative on failure
- *
- * Changes: None.
- *
*-------------------------------------------------------------------------
*/
static herr_t
@@ -1463,14 +1465,14 @@ H5FD__direct_ctl(H5FD_t *_file, uint64_t op_code, uint64_t flags, const void H5_
switch (op_code) {
- case H5FD_CTL__GET_TERMINAL_VFD:
+ case H5FD_CTL_GET_TERMINAL_VFD:
HDassert(output);
*output = (void *)(file);
break;
/* Unknown op code */
default:
- if (flags & H5FD_CTL__FAIL_IF_UNKNOWN_FLAG)
+ if (flags & H5FD_CTL_FAIL_IF_UNKNOWN_FLAG)
HGOTO_ERROR(H5E_VFL, H5E_FCNTL, FAIL, "unknown op_code and fail if unknown flag is set")
break;
}
@@ -1438,15 +1443,12 @@ done:
*
* At present, the only op code supported is
- * H5FD_CTL__GET_TERMINAL_VFD, which is used to obtain the
+ * H5FD_CTL_GET_TERMINAL_VFD, which is used to obtain the
* instance of H5FD_t associated with the terminal
* VFD. This allows comparison of files whose terminal